@@ -1,9 +1,9 @@
 /*
  * DemoConfigurationPage.h - header for the DemoConfigurationPage class
  *
- * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2025 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -22,8 +22,7 @@
  *
  */
 
-#ifndef DEMO_CONFIGURATION_PAGE_H
-#define DEMO_CONFIGURATION_PAGE_H
+#pragma once
 
 #include "ConfigurationPage.h"
 
@@ -37,8 +36,8 @@ class DemoConfigurationPage : public ConfigurationPage
 {
 	Q_OBJECT
 public:
-	DemoConfigurationPage( DemoConfiguration& configuration, QWidget* parent = nullptr );
-	~DemoConfigurationPage();
+	explicit DemoConfigurationPage( DemoConfiguration& configuration, QWidget* parent = nullptr );
+	~DemoConfigurationPage() override;
 
 	void resetWidgets() override;
 	void connectWidgetsToProperties() override;
@@ -51,5 +50,3 @@ private:
 	DemoConfiguration& m_configuration;
 
 };
-
-#endif // DEMO_CONFIGURATION_PAGE_H
